The Unit Root Tests
===================

.. module:: arch.unitroot
   :synopsis: Unit root tests

.. currentmodule:: arch.unitroot

.. autosummary::
   :toctree: generated/

   ADF
   DFGLS
   PhillipsPerron
   ZivotAndrews
   VarianceRatio
   KPSS

Automatic Bandwidth Selection
-----------------------------

.. autosummary::
   :toctree: generated/

   auto_bandwidth
